@@ -2,8 +2,8 @@ import click
 
 @click.command(name='run_pulls')
 @click.option('-i', '--input_file', required=True, help='Path to the input workspace file')
-@click.option('-w', '--workspace', default='combWS', help='Name of workspace')
-@click.option('-m', '--model_config', default='ModelConfig', help='Name of model config')
+@click.option('-w', '--workspace', default=None, help='Name of workspace. Auto-detect by default.')
+@click.option('-m', '--model_config', default=None, help='Name of model config. Auto-detect by default.')
 @click.option('-d', '--data', default='combData', help='Name of dataset')
 @click.option('-p', '--parameter', default='', help='Nuisance parameter(s) to run pulls on.'+\
                                                     'Multiple parameters are separated by commas.'+\
@@ -93,8 +93,8 @@ def plot_pulls(**kwargs):
 @click.option('--outdir', default='likelihood_scan', help='Output directory.')
 @click.option('--vmin', type=float, default=10, help='Minimum range of POI relative to the central value during likelihood calculation.')
 @click.option('--vmax', type=float, default=10, help='Maximum range of POI relative to the central value during likelihood calculation.')
-@click.option('-w', '--workspace', default='combWS', help='Name of workspace.')
-@click.option('-m', '--model_config', default='ModelConfig', help='Name of model config.')
+@click.option('-w', '--workspace', default=None, help='Name of workspace. Auto-detect by default.')
+@click.option('-m', '--model_config', default=None, help='Name of model config. Auto-detect by default.')
 @click.option('-d', '--data', default='combData', help='Name of dataset.')
 @click.option('-s', '--snapshot', default=None, help='Name of initial snapshot')
 @click.option('-r', '--profile', default="", help='Parameters to profile')
@@ -125,12 +125,30 @@ def likelihood_scan(**kwargs):
     from quickstats.components.likelihood import scan_nll
     scan_nll(**kwargs)
 
-
-
 @click.command(name='compile')
 def compile_macros():
     """
     Compile ROOT macros
     """
     from quickstats.utils.root_utils import compile_macro
-    compile_macro("RooTwoSidedCBShape")
\ No newline at end of file
+    compile_macro("RooTwoSidedCBShape")
+    
+    
+@click.command(name='harmonize_np')
+@click.option('ws_files', nargs=-1)
+@click.option('-r', '--reference', required=True, help='Path to reference json file containing renaming scheme')
+@click.option('-i', '--input_config_path', default=None, help='Path to json file containing input workspace paths')
+@click.option('-b', '--base_path', default='./', help='Base path for input config')
+@click.option('-o', '--outfile', default='renamed_np.json', help='Output filename')
+def harmonize_np(ws_files, reference, input_list, base_path, outfile):
+    """
+    Harmonize NP names across different workspaces
+    """
+    from quickstats.components import NuisanceParameterHarmonizer
+    harmonizer = NuisanceParameterHarmonizer(reference)
+    if (len(ws_files) > 0) and input_list is not None:
+        raise RuntimeError('either workspace paths or json file containing workspace paths should be given')
+    if len(ws_files) > 0:
+        harmonizer.harmonize(ws_files, outfile=outfile)
+    elif (input_list is not None):
+        harmonizer.harmonize_multi_input(input_list, base_path, outfile=outfile)
\ No newline at end of file
